/* am930debug.h: Debugging macros and declarations
*	--------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*
*	--------------------------------------------------------------------
*/
#ifndef _LINUX_AM930DEBUG_H
#define _LINUX_AM930DEBUG_H

#include <wlan/wlan_compat.h>

/* These constants control which files/objects have their debugging 
	messages turned on */
#define DBHW	BIT0
#define DBMAC	BIT1
#define DBMGR	BIT2
#define DBLLC	BIT3
#define DBDI	BIT4
#define DBCS	BIT5

/* This bit turns on file entry/exit messages (if the file is enabled) */
#define DBFUNC	BIT8

/* This bit turns on messages relating to driver initialization and shutdown */
#define DBINIT	BIT12

/* Turns on card services event messages */
#define DBCSEVENT	BIT13

/* Turns on ISR related messages */
#define DBINT		BIT14

/* These bits turn on messages regarding packet travels through the driver */
#define DBTXPATH	BIT16
#define DBRXPATH	BIT17

/* These bits will enable messages showing the contents of each packet */
#define DBTXDATA	BIT18
#define DBRXDATA	BIT19

/* These bits enable the messages regarding the receipt and handling of commands
	by the mgr object, also messages regarding state changes within the mgr */
#define DBMGRCMD	BIT20
#define DBMGRSTATE	BIT21

/* These bits control messages in regards to firmware commands and state */
#define DBFWCMD		BIT24
#define DBFWINT		BIT25
#define DBFWSTATE	BIT26

/*----------------------------------------------------------------
	dbmask is a global variable that is set via the makefile
	and can be modified via the argument to insmod. It controls
	which of the debug print messages are enabled. To disable
	ALL of them and remove the code for them, don't define
	the  DBMSG symbol when compiling. The constants above provide
	the values. dbmask is defined in am930cs.c
-----------------------------------------------------------------*/
extern UINT32	dbmask;

#ifdef DBMSG_ENABLED
	#define DBPRT(dbtype, fmt, args...) \
	{ \
		if ( (dbmask & FILEBIT) && (dbmask & (dbtype)) ) \
			printk( KERN_DEBUG __FUNCTION__ ": " fmt, ## args ); \
	}

	#define DBRXFRMPRT( dbtype, rxtype, frm )

/*
	#define DBRXFRMPRT( dbtype, rxtype, frm ) \
	{ \
		if ( (dbmask & FILEBIT) && (dbmask & (dbtype)) ) \
			printk_rxfrm_t( (rxtype), (frm), (dbtype) & DBRXDATA ); \
	}
*/
#else

	#define DBPRT(type, format, args...) 
	#define DBRXFRMPRT( dbtype, rxtype, frm )

#endif


#define DBFENTER	DBPRT( DBFUNC, "Entered\n" )
#define DBFEXIT		DBPRT( DBFUNC, "Exited\n" )

/* some functions to help... */
struct am930rxframe;

void printk_am930rxfrm_t(char *frmtype, struct am930rxframe *frm, int dodump );
void printk_hexdump( UINT8 *p, UINT len);

#endif
