/* am930mac.h: Handles the 802.11 mac functions
*	--------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*
*	--------------------------------------------------------------------
*/

#ifndef _LINUX_AM930MAC_H
#define _LINUX_AM930MAC_H

/*=============================================================*/
/*--- Constants -----------------------------------------------*/
/*=============================================================*/

#define WLAN_MODE_NOTJOINED	0
#define WLAN_MODE_ADHOC		1
#define WLAN_MODE_INFRA		2

/*=============================================================*/
/*--- Types ---------------------------------------------------*/
/*=============================================================*/
struct am930hw;
struct am930llc;
struct am930mgr;

/* received frames, passed up from hw */
typedef struct am930rxframe
{
	UINT32	len;
	UINT32	local_time;
	UINT8	rssi;
	UINT8	ch;
	UINT8	rate;
	UINT8	data[0];
} am930rxfrm_t;

/* Ethernet header for SUTRO implementation */
typedef struct am930mac_eth
{
	UINT48	dest	__GNUC_PACK__;
	UINT48	src		__GNUC_PACK__;
	UINT8	type[2]	__GNUC_PACK__;
} am930mac_eth_t;

/* SUTRO data frame format */
typedef struct am930mac_datafrm
{
	UINT8			hdr[24]	__GNUC_PACK__;
	am930mac_eth_t	eth		__GNUC_PACK__;
	UINT8			data[0]	__GNUC_PACK__;
} am930mac_datafrm_t;


/* mac class structure */
typedef struct am930mac
{
	/* References to other objects */
	dev_link_t		*di;
	struct am930hw	*hw;
	struct am930llc	*llc;
	struct am930mgr	*mgr;

	/* State variables */
	UINT			wlan_mode;

} am930mac_t;


/*=============================================================*/
/*--- Methods -------------------------------------------------*/
/*=============================================================*/

am930mac_t *am930mac_construct(dev_link_t *di, UINT32 membase);
void am930mac_destruct( am930mac_t *mac );

/* Instructors/Modifiers */
UINT32 am930mac_txdata( am930mac_t *mac, UINT8 *daddr, UINT8 *saddr, 
						UINT8 *frm, UINT32 len);

/*
init_data_tx	(called in response to llc.open)
shutdown		(called in response to llc.stop)
make_dataheader	(called in response to llc.hard_header)
xmit_dataframe	(called in response to llc.hard_start_xmit)
xmit_mgmtframe
*/

/* Event handlers */
void am930mac_ISR( am930mac_t *mac );
void am930mac_ontxcomplete( am930mac_t *mac, UINT32 txresult );
void am930mac_rxframe( am930mac_t *mac, am930rxfrm_t *frm);
void am930mac_rxframe_err( am930mac_t *mac);

/* Helpers */
am930rxfrm_t *am930mac_mk_rxfrmbuf( am930mac_t *mac, UINT32 len );

#endif  /* _LINUX_AM930MAC_H */
