/* am930mgr.h: Handles the 802.11 mac managment functions
*	--------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*
*	--------------------------------------------------------------------
*/

#ifndef _LINUX_AM930MGR_H
#define _LINUX_AM930MGR_H

/*=============================================================*/
/*--- Constants -----------------------------------------------*/
/*=============================================================*/
#define MGR_ISJOINED	BIT0
#define MGR_ISSCANNING	BIT1

/*=============================================================*/
/*--- Types ---------------------------------------------------*/
/*=============================================================*/
typedef struct knownbss
{
	/* BSS info */
	UINT48			bssid;			/* primary key */
	UINT32			channel;
	UINT32			rate;
	UINT16			bcn_int;
	UINT16			cap_info;
        wlan_ie_ssid_t          ssid;
	wlan_bss_ts_t	bss_timestamp;
	UINT32			sutro_reftime;	/* am930 specific */

	/* Driver support */
	UINT32			ttl;			/* TODO: add aging of BSS's */
	struct knownbss	*next;
} knownbss_t;

typedef struct am930mgr
{
	/* general state vars */
	am930mac_t	*mac;
	am930hw_t	*hw;
	UINT32		state;
	UINT32		curr_ch;
	UINT32		curr_rate;
	UINT8		curr_ssid[WLAN_SSID_MAXLEN+2+1];  /* extra for \0 */
	UINT8		curr_bssid[WLAN_BSSID_LEN];
	UINT16		curr_cap_info;
	UINT16		curr_aid;
	UINT		is_authen;

	/* scan state vars */
	UINT		scantype;	/* 0 = passive, 1 = active */
	UINT		scanch;		/* curr. scan channel */
	UINT		scanendch;	/* last ch. in scan seq. */
	UINT		scantimech;	/* Kus spent scanning each ch. */
	UINT48		scanbssid;	/* bssid to scan for (usually bcast) */
	UINT		scanbsstype;/* BIT0:independent,BIT1:infrastructure */

	/* list of known bss's */
	knownbss_t	*bsslist;

} am930mgr_t;

/*=============================================================*/
/*--- Methods -------------------------------------------------*/
/*=============================================================*/

am930mgr_t* am930mgr_construct(am930mac_t *mac, am930hw_t *hw);
void am930mgr_destruct( am930mgr_t *mgr );

void am930mgr_authen_begin_sta(am930mgr_t *mgr);
void am930mgr_authen_rx( am930mgr_t *mgr, am930rxfrm_t *frm);

UINT32 am930mgr_createbss(	am930mgr_t *mgr, UINT32 ch, char *ssid,
							UINT32 bcn, UINT32 atimwindow);
UINT32 am930mgr_joinbss( am930mgr_t *mgr, UINT48 bssid );

UINT32 am930mgr_mibget( am930mgr_t *mgr, UINT32 mibsec, UINT32 len, void *buf);
UINT32 am930mgr_mibset( am930mgr_t *mgr, UINT32 mibsec, UINT32 len, void *buf);
UINT32 am930mgr_mibgetitem( am930mgr_t *mgr, UINT32 itemid, 
							void *buf, UINT32 len);
UINT32 am930mgr_mibsetitem( am930mgr_t *mgr, UINT32 itemid, 
							void *buf, UINT32 len);

void am930mgr_prstatus(am930mgr_t *mgr, UINT16 status );

void am930mgr_rxmgmt( am930mgr_t *mgr, am930rxfrm_t *frm);
UINT32 am930mgr_scan( am930mgr_t *mgr, UINT scantype, UINT bsstype,
						UINT48 bssid, UINT startch, UINT endch, UINT timech);

#endif /* _LINUX_AM930LLC_H */


