/* wlan_ioctl.h: Declares constants and types for the private ioctls
*	--------------------------------------------------------------------
*
*   Linux WLAN 
*
*   The contents of this file are subject to the Mozilla Public
*   License Version 1.0 (the "License"); you may not use this file
*   except in compliance with the License. You may obtain a copy of
*   the License at http://www.mozilla.org/MPL/
*
*   Software distributed under the License is distributed on an "AS
*   IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
*   implied. See the License for the specific language governing
*   rights and limitations under the License.
*
*   The initial developer of the original code is Mark S. Mathews
*   <mark@absoval.com>.  Portions created by Mark S. Mathews
*   are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
*    
*	--------------------------------------------------------------------
*/

#ifndef _LINUX_WLAN_IOCTL_H
#define _LINUX_WLAN_IOCTL_H

/* ioctl cmd codes */
#define WLAN_TEST			(SIOCDEVPRIVATE + 0)
#define WLAN_SCAN			(SIOCDEVPRIVATE + 1)
#define WLAN_NETLIST_LEN	(SIOCDEVPRIVATE + 2)
#define WLAN_NETLIST		(SIOCDEVPRIVATE + 3)
#define WLAN_BSSCREATE		(SIOCDEVPRIVATE + 4)
#define WLAN_BSSJOIN		(SIOCDEVPRIVATE + 5)
#define WLAN_GETMIB			(SIOCDEVPRIVATE + 6)
#define WLAN_GETMIBITEM		(SIOCDEVPRIVATE + 7)
#define WLAN_SETMIBITEM		(SIOCDEVPRIVATE + 8)

typedef struct wlan_req
{
	char 	name[16]	__GNUC_PACK__;
	void	*data		__GNUC_PACK__;
	UINT16	result		__GNUC_PACK__;
	UINT16	len			__GNUC_PACK__;
} wlan_req_t;

#define BSSTYPE_IND		BIT0
#define BSSTYPE_INFRA	BIT1

typedef struct wlan_scan
{
	UINT	scantype;
	UINT	bsstype;
	UINT48	bssid;
	UINT	startch;
	UINT	endch;
	UINT	timech;
} wlan_scan_t;

typedef struct wlan_netlist_len
{
	UINT	nitems;
} wlan_netlist_len_t;

typedef struct netitem
{
	UINT	channel;
	UINT48	bssid;
	UINT	bcn_int;
	UINT16	cap_info;
	UINT8	ssid[WLAN_SSID_MAXLEN];
} netitem_t;

typedef struct wlan_netlist
{
	UINT		nitems;
	netitem_t	netlist[0];
} wlan_netlist_t;

typedef struct wlan_bsscreate
{
	UINT32	channel;
	char	ssid[WLAN_SSID_MAXLEN];
	UINT32	beacon_int;
	UINT32	atim_win;
} wlan_bsscreate_t;

typedef struct wlan_bssjoin
{
	UINT48	bssid;
} wlan_bssjoin_t;

typedef struct wlan_getmib
{
	UINT32	mibcode;
	union _data
	{
		su_mib_local_t				local;
		su_mib_mac_addr_stat_grp_t	addr;
		su_mib_mac_t				mac;
		su_mib_mac_statistics_t		stats;
		su_mib_mac_mgmt_t			mgmt;
		su_mib_drvr_mac_mgmt_t		drvr;
		su_mib_phy_t				phy;
	} data;
} wlan_getmib_t;

#endif
