/*

    Linux WLAN 

    The contents of this file are subject to the Mozilla Public
    License Version 1.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a copy of
    the License at http://www.mozilla.org/MPL/

    Software distributed under the License is distributed on an "AS
    IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
    implied. See the License for the specific language governing
    rights and limitations under the License.

    The initial developer of the original code is Mark S. Mathews
    <mark@absoval.com>.  Portions created by Mark S. Mathews
    are Copyright (C) 1998 AbsoluteValue Software, Inc.  All Rights Reserved.
    
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

/* Ugly hack for LinuxPPC R4, don't have time to figure it out right now */
#if defined(_ARCH_PPC)
#undef __GLIBC__
#endif


#include <sys/socket.h>
#include <sys/types.h>
#include <sys/ioctl.h>
#include <wlan/version.h>
#include <wlan/wlan_compat.h>
#include <wlan/am930mib.h>
#include <wlan/wlan_ioctl.h>
#include "prmib.h"

void usage(void);
int  getmib( int fd, char *interface, UINT32 mibcode );
void strtoUINT48( UINT48 a, char *s );
void pr_netlist(wlan_netlist_t *list);

char *appname;

int main(int argc, char *argv[])
{
	int result = 0;
	int fd;
	wlan_req_t	req;

	appname = argv[0];

	if ( argc >=  2 )
	{
		
		if ( strcasecmp(argv[1], "version") == 0 )
		{
			printf("%s version " WLAN_RELEASE "\n", argv[0]);
			return result;
		}

		/* get a socket */
		fd = socket(AF_INET, SOCK_STREAM, 0);
		if ( fd != -1 )
		{
			/* Test that there is a card */
			strcpy( req.name, argv[1]);
			req.result = 0;
			req.data = NULL;
			req.len = 0;
			result = ioctl( fd, WLAN_TEST, &req);
			if (result < 0)
			{
				fprintf(stderr, "%s: card detect ioctl failed!\n", appname);
			}
			else
			{
				if ( req.result == 0xf0f0 )
				{
					/* now, what does the user want? */
					if ( argc > 2 )
					{
						/* ok, there's more arguments */
						if ( strcasecmp(argv[2], "scan") == 0 )
						{
							if ( argc < 9 )
							{
								fprintf(stderr,
									"wlanctl: Did we leave something out?\n");
								usage();
							}
							else
							{
								wlan_req_t	req;
								wlan_scan_t cmd;
								strcpy( req.name, argv[1]);
								req.result = 0;
								req.data = &cmd;
								req.len = sizeof(cmd);
								cmd.startch = atoi( argv[3] );
								cmd.endch = atoi( argv[4] );
								cmd.timech = atoi( argv[5] );
								strtoUINT48( cmd.bssid, argv[6] );
								if (strcmp(argv[7], "both") == 0 )
								{
									cmd.bsstype = BSSTYPE_IND | BSSTYPE_INFRA;
								}
								else if ( strcmp(argv[7], "independent") == 0 )
								{
									cmd.bsstype = BSSTYPE_IND;
								}
								else
								{
									cmd.bsstype = BSSTYPE_INFRA;
								}
								if ( strcmp( argv[8], "active") == 0 )
								{
									cmd.scantype = 0;
								}
								else
								{
									cmd.scantype = 1;
								}
								result = ioctl( fd, WLAN_SCAN, &req);
								switch( req.result)
								{
									case 0: 
										printf("wlanctl: scan begun\n");
										break;
									case 1: 
										fprintf(stderr, "wlanctl: command discarded, driver is already scanning\n");
										break;
									case 2: 
										fprintf(stderr, "wlanctl: h/w scan command failed!\n");
										break;
									default:
										fprintf(stderr, "wlanctl: unknown error.\n");
										break;
								}
							}
						}
						else if ( strcasecmp(argv[2], "netlist") == 0 )
						{
							wlan_req_t			req;
							wlan_netlist_len_t	cmd1;
							wlan_netlist_t		*cmd2;
							strcpy( req.name, argv[1]);
							req.result = 0;
							req.data = &cmd1;
							req.len = sizeof(cmd1);
							result = ioctl( fd, WLAN_NETLIST_LEN, &req);
							if ( result || req.result )
							{
								fprintf(stderr,"wlanctl: netlist_len cmd failed.\n");
							}
							else
							{
								cmd2 = malloc( sizeof(wlan_netlist_t) + (cmd1.nitems * sizeof(netitem_t)));
								cmd2->nitems = cmd1.nitems;
								req.result = 0;
								req.data = cmd2;
								req.len = sizeof(wlan_netlist_t) + (cmd1.nitems * sizeof(netitem_t));
								result = ioctl( fd, WLAN_NETLIST, &req);
								if ( result || req.result )
								{
									fprintf(stderr,"wlanctl: netlist cmd failed.\n");
								}
								else
								{
									pr_netlist( cmd2 );
								}
							}
						}
						else if ( strcasecmp(argv[2], "bsscreate") == 0 )
						{
							if (argc < 7)
							{
								fprintf(stderr,
									"wlanctl: Did we leave something out?\n");
								usage();
							}
							else
							{
								wlan_req_t	req;
								wlan_bsscreate_t cmd;
								strcpy( req.name, argv[1]);
								req.result = 0;
								req.data = &cmd;
								req.len = sizeof(cmd);
								cmd.channel = atoi(argv[3]);
								cmd.beacon_int = atoi(argv[4]);
								cmd.atim_win = atoi(argv[5]);
								strcpy( cmd.ssid, argv[6]);
								result = ioctl( fd, WLAN_BSSCREATE, &req);
								if ( result )
								{
									fprintf(stderr, 
										"wlanctl: Something didn't work.\n");
								}
							}
						}
						else if ( strcasecmp(argv[2], "bssjoin") == 0 )
						{
							wlan_req_t			req;
							wlan_bssjoin_t		cmd;

							if ( argc < 4 )
							{
								fprintf(stderr, 
									"wlanctl: Did we forget something?.\n");
								usage();
								exit(1);
							}
							else
							{
								strcpy( req.name, argv[1]);
								req.result = 0;
								req.data = &cmd;
								req.len = sizeof(cmd);
								strtoUINT48( cmd.bssid, argv[3] );
								result = ioctl( fd, WLAN_BSSJOIN, &req);
								if ( req.result )
								{
									fprintf(stderr,
		"wlanctl: Either the bssid was bogus or the sync command failed.\n");
								}
							}
						}
						else if ( strcasecmp(argv[2], "getmib") == 0 )
						{
							/* ok, which mib? */
							if ( argc >= 4 )
							{
								UINT32	mibcode;
								mibcode = atoi(argv[3]);
								result = getmib( fd, argv[1], mibcode );
							}
							else
							{
								/* OK, print them all */
								result = getmib( fd, argv[1], SUMIB_LOCAL);
								result = getmib( fd, argv[1], SUMIB_ADDR);
								result = getmib( fd, argv[1], SUMIB_MAC);
								result = getmib( fd, argv[1], SUMIB_STAT);
								result = getmib( fd, argv[1], SUMIB_MGMT);
								result = getmib( fd, argv[1], SUMIB_DRVR);
								result = getmib( fd, argv[1], SUMIB_PHY);
							}
						}
						else if ( strcasecmp(argv[2], "getmibitem") == 0 )
						{
							fprintf(stderr, "%s: cmd currently unsupported\n", 
									argv[0]);
						}
						else if ( strcasecmp(argv[2], "setmibitem") == 0 )
						{
							fprintf(stderr, "%s: cmd currently unsupported\n", 
									argv[0]);
						}
						else
						{
							fprintf(stderr, "%s: unknown command\n", argv[0]);
							usage();
						}
					}
					else
					{
						/* ok, we just want a general status msg */
						/* maybe some stats, joined?, ESSID, BSSID etc. */
						printf("some general stats\n");
					}

				}
				else
				{
					fprintf(stderr,"%s: ioctl successful but driver not responding!\n", argv[0]);
					result = 1;
				}
			}
		}
		else
		{
			fprintf(stderr, "%s: No appropriate sockets!\n", argv[0]);
		}
	}
	else
	{
		usage();
		result = 1;
	}
	return result;
}

int  getmib( int fd, char *interface, UINT32 mibcode )
{
	wlan_req_t 		req;
	wlan_getmib_t	mib;
	int 			result = 0;

	strcpy( req.name, interface);
	req.len = sizeof(wlan_getmib_t);
	req.data = &mib;
	req.result = 0;
	mib.mibcode = mibcode;

	result = ioctl( fd, WLAN_GETMIB, &req);

	if ( result == 0 )
	{
		switch (mibcode)
		{
			case SUMIB_LOCAL:
				prlocalmib( &mib.data.local ); 
				break;
			case SUMIB_ADDR:
				praddrmib( &mib.data.addr ); 
				break;
			case SUMIB_MAC:
				prmacmib( &mib.data.mac ); 
				break;
			case SUMIB_STAT:
				prstatsmib( &mib.data.stats ); 
				break;
			case SUMIB_MGMT:
				prmgmtmib( &mib.data.mgmt ); 
				break;
			case SUMIB_DRVR:
				prdrvrmib( &mib.data.drvr ); 
				break;
			case SUMIB_PHY:
				prphymib( &mib.data.phy ); 
				break;
		}
	}
	else
	{
		fprintf(stderr, "wlanctl: ioctl failed.\n");
	}

	return result;
}

void usage(void)
{
	printf("wlanctl : control utility for am79C930 based DS wlan cards\n");
	printf("   usage: wlanctl interface [cmd [cmdarg ...]]\n\n");
}

void strtoUINT48( UINT48 a, char *s )
{
	char	*p;
	int		i;
	UINT	val;

	for ( i = 0; i < 5; i++)
	{
		p = strchr( s, ':');
		if ( p == NULL )
		{
			fprintf(stderr, "UINT48 format error!\n");
			exit(1);
		}
		else
		{
			*p = '\0';
			sscanf( s, "%x", &val);
			a[i] = (UINT8)val;
			s = p+1;
		}
	}
	sscanf( s, "%x", &val);
	a[i] = (UINT8)val;
}

void pr_netlist(wlan_netlist_t *list)
{
	int i;
	char buf[80];
	for ( i = 0; i < list->nitems; i++)
	{
		printf("ch  bssid              bcn   cap_info  ssid\n");
		printf("------------------------------------------------------\n");
		printf("%02d  ", list->netlist[i].channel);
		mac2str( list->netlist[i].bssid, buf);
		printf("%s  ", buf);
		printf("%04d  ", list->netlist[i].bcn_int);
		printf("0x%04x  ", list->netlist[i].cap_info);
		printf("%s\n", list->netlist[i].ssid);
	}
}
